@@ -2,7 +2,6 @@
 
 
 #include <stdio.h>
-#include <sys/random.h>
 
 #include "../main.hpp"
 #include "../tpm1x.hpp"
@@ -44,7 +43,7 @@ int main(int argc, char ** argv) {
 					    TRY_TPM1X(buf, Tspi_TPM_PcrRead(tpm_h, pcrs[i], &val_len, &val));
 				    else {
 					    BYTE data[TPM_SHA1_160_HASH_LEN];
-					    getrandom(data, sizeof(data), 0);
+					    getentropy(data, sizeof(data));
 					    TRY_TPM1X(buf, Tspi_TPM_PcrExtend(tpm_h, pcrs[i], sizeof(data), data, nullptr, &val_len, &val));
 				    }
 
