@@ -25,20 +25,19 @@ _get_backend() {
 
 _install_tpm2() {
 	inst_binary zfs-tpm2-load-key
-	# shellcheck disable=SC2046
-	inst_library $(find /usr/lib -name 'libtss2-tcti*.so*')  # TODO: there's got to be a better way™!
+	inst_libdir_file 'libtss2-tcti*.so*'
 	command -v tpm2_dictionarylockout > /dev/null && inst_binary tpm2_dictionarylockout
 }
 
 _install_tpm1x() {
 	inst_binary zfs-tpm1x-load-key
-	INSTALL_TPM1X{inst_binary tcsd; inst_binary ip; inst_binary ss, initdir, inst_simple, inst_simple, inst_simple, inst_library}
+	INSTALL_TPM1X{inst_binary tcsd; inst_binary ip; inst_binary ss, initdir, inst_simple, inst_simple, inst_simple, inst_libdir_file}
 	command -v tpm_resetdalock > /dev/null && inst_binary tpm_resetdalock
 }
 
 
 check() {
-	command -v zfs-tpm-list > /dev/null || return 1
+	require_binaries zfs-tpm-list || return
 
 	# shellcheck disable=SC2154
 	if [ -n "$hostonly" ]; then
