@@ -2,7 +2,7 @@
 .
 .Sh TPM2 back-end configuration
 .Ss Environment variables
-.Bl -tag -compact -width "TSS2_LOG"
+.Bl -tag -compact -width ".Ev TSS2_LOG"
 .It Ev TSS2_LOG
 Any of:
 .Sy NONE , ERROR , WARNING , INFO , DEBUG , TRACE .
