@@ -8,7 +8,9 @@ ThePhD
 .It
 Embark Studios
 .It
-Lars Strojny
+Jasper Bekkers
+.It
+EvModder
 .El
 .
 .Sh REPORTING BUGS
