@@ -8,6 +8,5 @@
 
 
 int main(int argc, char ** argv) {
-	return do_clear_main(
-	    argc, argv, THIS_BACKEND, [](auto, auto) { return 0; }, [] { return 0; });
+	return do_clear_main(argc, argv, THIS_BACKEND, [](auto, auto) { return 0; }, [] { return 0; });
 }
