@@ -64,8 +64,7 @@ static int do_bare_main(
 }
 
 template <class G, class M, class V = int (*)()>
-static int do_main(
-    int argc, char ** argv, const char * getoptions, const char * usage, G && getoptfn, M && main, V && validate = [] { return 0; }) {
+static int do_main(int argc, char ** argv, const char * getoptions, const char * usage, G && getoptfn, M && main, V && validate = [] { return 0; }) {
 	return do_bare_main(
 	    // as-in argument in a usage string
 	    argc, argv, getoptions, usage, gettext_noop("dataset"), getoptfn,
