@@ -9,6 +9,7 @@
 #include "main.hpp"
 
 #include <stdlib.h>
+#include <sys/mman.h>
 
 #include <tss/platform.h>
 #include <tss/tspi.h>
@@ -29,6 +30,8 @@ static const constexpr uint8_t parent_key_secret[TPM_SHA1_160_HASH_LEN]{0xCE, 0x
 
 template <class F>
 int with_tpm1x_session(F && func) {
+	mlockall(MCL_CURRENT | MCL_FUTURE);
+
 	TSS_HCONTEXT ctx{};  // All memory lives as long as this does
 	TRY_TPM1X("create TPM context", Tspi_Context_Create(&ctx));
 
