@@ -9,7 +9,8 @@
 #include <algorithm>
 #include <inttypes.h>
 #include <iterator>
-#define OPENSSL_SUPPRESS_DEPRECATED  // SHA256_*(); supposedly replaced with EVP* but that's horseshit. we'll see how she turns out, given there's no reason given
+#define OPENSSL_SUPPRESS_DEPRECATED  // SHA256_*(); supposedly replaced with EVP* but that's horseshit. we'll see how she turns out, given there's no reason
+                                     // given
 #include <openssl/sha.h>
 #include <optional>
 #include <utility>
@@ -20,7 +21,7 @@ static int try_or_passphrase(const char * what, const char * what_for, ESYS_CONT
 	auto err = func();
 	for(int i = 0; err == TPM2_RC_9 + valid_error && i < 3; ++i) {
 		if(i)
-			fprintf(stderr, "Couldn't %s: %s\n", what, Tss2_RC_Decode(err));
+			fprintf(stderr, "Couldn't %s: %s\n", gettext(what), Tss2_RC_Decode(err));
 
 		uint8_t * pass{};
 		size_t pass_len{};
@@ -37,7 +38,7 @@ static int try_or_passphrase(const char * what, const char * what_for, ESYS_CONT
 
 	// TRY_TPM2() unrolled because no constexpr/string-literal-template arguments until C++20, which is not supported by GCC 8, which we need for Buster
 	if(err != TPM2_RC_SUCCESS)
-		return fprintf(stderr, "Couldn't %s: %s\n", what, Tss2_RC_Decode(err)), __LINE__;
+		return fprintf(stderr, "Couldn't %s: %s\n", gettext(what), Tss2_RC_Decode(err)), __LINE__;
 	return 0;
 }
 
@@ -112,7 +113,8 @@ int tpm2_parse_pcrs(char * arg, TPML_PCR_SELECTION & pcrs) {
 			++per_hash;
 
 		if(bank == pcrs.pcrSelections + (sizeof(pcrs.pcrSelections) / sizeof(*pcrs.pcrSelections)))  // == TPM2_NUM_PCR_BANKS
-			return fprintf(stderr, "Too many PCR banks specified! Can only have up to %zu\n", sizeof(pcrs.pcrSelections) / sizeof(*pcrs.pcrSelections)), __LINE__;
+			return fprintf(stderr, gettext("Too many PCR banks specified! Can only have up to %zu\n"), sizeof(pcrs.pcrSelections) / sizeof(*pcrs.pcrSelections)),
+			       __LINE__;
 
 		if(auto sep = strchr(per_hash, ':')) {
 			*sep        = '\0';
@@ -127,8 +129,9 @@ int tpm2_parse_pcrs(char * arg, TPML_PCR_SELECTION & pcrs) {
 				if(!parse_uint(per_hash, bank->hash) || !std::binary_search(std::begin(tpm2_hash_algs), std::end(tpm2_hash_algs), tpm2_hash_algs_t{bank->hash, {}},
 				                                                            [&](auto && lhs, auto && rhs) { return lhs.alg < rhs.alg; })) {
 					fprintf(stderr,
-					        "Unknown hash algorithm %s.\n"
-					        "Can be any of case-insensitive ",
+					        // comma-separated list follows
+					        gettext("Unknown hash algorithm %s.\n"
+					                "Can be any of case-insensitive "),
 					        per_hash);
 					auto first = true;
 					for(auto && alg : tpm2_hash_algs)
@@ -157,7 +160,8 @@ int tpm2_parse_pcrs(char * arg, TPML_PCR_SELECTION & pcrs) {
 				}
 			}
 		} else
-			return fprintf(stderr, "PCR bank \"%s\": no algorithm; need alg:PCR[,PCR]...\n", per_hash), __LINE__;
+			// user-passed parameter
+			return fprintf(stderr, gettext("PCR bank \"%s\": no algorithm; need alg:PCR[,PCR]…\n"), per_hash), __LINE__;
 	}
 
 	pcrs.count = bank - pcrs.pcrSelections;
@@ -299,8 +303,8 @@ static int tpm2_police_pcrs(ESYS_CONTEXT * tpm2_ctx, const TPML_PCR_SELECTION &
 	return with_session(pcr_session);
 }
 
-int tpm2_seal(const char * dataset, ESYS_CONTEXT * tpm2_ctx, ESYS_TR tpm2_session, TPMI_DH_PERSISTENT & persistent_handle,
-              const TPML_PCR_SELECTION & pcrs, bool allow_PCR_or_pass, void * data, size_t data_len) {
+int tpm2_seal(const char * dataset, ESYS_CONTEXT * tpm2_ctx, ESYS_TR tpm2_session, TPMI_DH_PERSISTENT & persistent_handle, const TPML_PCR_SELECTION & pcrs,
+              bool allow_PCR_or_pass, void * data, size_t data_len) {
 	ESYS_TR primary_handle = ESYS_TR_NONE;
 	quickscope_wrapper primary_handle_deleter{[&] { Esys_FlushContext(tpm2_ctx, primary_handle); }};
 
@@ -365,8 +369,9 @@ int tpm2_seal(const char * dataset, ESYS_CONTEXT * tpm2_ctx, ESYS_TR tpm2_sessio
 		memcpy(secret_sens.sensitive.data.buffer, data, secret_sens.sensitive.data.size);
 
 		if(!pcrs.count || allow_PCR_or_pass) {
-			char what_for[ZFS_MAX_DATASET_NAME_LEN + 38 + 1];
-			snprintf(what_for, sizeof(what_for), "%s TPM2 wrapping key (or empty for none)", dataset);
+			char what_for[ZFS_MAX_DATASET_NAME_LEN + 512 + 1];
+			// %s=dataset name, then TPM2. noun for "Enter passphrase for" prompt
+			snprintf(what_for, sizeof(what_for), gettext("%s %s wrapping key (or empty for none)"), dataset, "TPM2");
 
 			uint8_t * passphrase{};
 			size_t passphrase_len{};
@@ -415,8 +420,9 @@ int tpm2_seal(const char * dataset, ESYS_CONTEXT * tpm2_ctx, ESYS_TR tpm2_sessio
 int tpm2_unseal(const char * dataset, ESYS_CONTEXT * tpm2_ctx, ESYS_TR tpm2_session, TPMI_DH_PERSISTENT persistent_handle, const TPML_PCR_SELECTION & pcrs,
                 void * data, size_t data_len) {
 	// Esys_FlushContext(tpm2_ctx, tpm2_session);
-	char what_for[ZFS_MAX_DATASET_NAME_LEN + 18 + 1];
-	snprintf(what_for, sizeof(what_for), "%s TPM2 wrapping key", dataset);
+	char what_for[ZFS_MAX_DATASET_NAME_LEN + 512 + 1];
+	// %s=dataset name, then TPM2. noun for "Enter passphrase for" prompt
+	snprintf(what_for, sizeof(what_for), gettext("%s %s wrapping key"), dataset, "TPM2");
 
 	// Entirely fake and not flushable (tpm:parameter(1):value is out of range or is not correct for the context)
 	ESYS_TR pandle;
@@ -430,7 +436,7 @@ int tpm2_unseal(const char * dataset, ESYS_CONTEXT * tpm2_ctx, ESYS_TR tpm2_sess
 		// In case there's (PCR policy || passphrase): try PCR once; if it fails, fall back to passphrase
 		if(pcr_session != ESYS_TR_NONE) {
 			if(auto err = unseal(pcr_session); err != TPM2_RC_SUCCESS)
-				fprintf(stderr, "Couldn't %s with PCR policy: %s\n", "unseal wrapping key", Tss2_RC_Decode(err));
+				fprintf(stderr, gettext("Couldn't unseal wrapping key with PCR policy: %s\n"), Tss2_RC_Decode(err));
 			else
 				return 0;
 		}
